Training
========
.. automodapi:: pykeen.training
    :no-heading:
    :no-inheritance-diagram:
    :headings: --
    :skip: TrainingCallback

Callbacks
---------
.. automodapi:: pykeen.training.callbacks
    :no-heading:
    :headings: ~~

Learning Rate Schedulers
------------------------
.. automodapi:: pykeen.lr_schedulers
    :no-heading:
    :headings: ~~
